Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(329)

Unified Diff: net/quic/quic_packet_creator.h

Issue 11958018: Queueing QUIC frames to be resent instead of packets and packing RST frames with acks and congestio… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/quic/quic_packet_creator.h
diff --git a/net/quic/quic_packet_creator.h b/net/quic/quic_packet_creator.h
index 62d54c27fef015883f335b249303ecbec7c2cb55..4f11348a70ee0e8e7f764156f70901381909bb40 100644
--- a/net/quic/quic_packet_creator.h
+++ b/net/quic/quic_packet_creator.h
@@ -52,30 +52,27 @@ class NET_EXPORT_PRIVATE QuicPacketCreator : public QuicFecBuilderInterface {
typedef std::pair<QuicPacketSequenceNumber, QuicPacket*> PacketPair;
+ // Serializes all frames into a single packet. All frames must fit into a
+ // single packet.
+ PacketPair SerializeAllFrames(const QuicFrames& frames);
+
// Serializes as many non-fec frames as can fit into a single packet.
// num_serialized is set to the number of frames serialized into the packet.
PacketPair SerializeFrames(const QuicFrames& frames, size_t* num_serialized);
// Converts a raw payload to a series of QuicPackets. Returns the number of
// bytes consumed from data.
// If data is empty and fin is true, the expected behavior is to consume the
// fin but return 0.
size_t DataToStream(QuicStreamId id,
base::StringPiece data,
QuicStreamOffset offset,
bool fin,
- std::vector<PacketPair>* packets);
-
- PacketPair ResetStream(QuicStreamId id,
- QuicStreamOffset offset,
- QuicErrorCode error);
+ std::vector<PacketPair>* packets,
+ QuicFrames* packetized_frames);
PacketPair CloseConnection(QuicConnectionCloseFrame* close_frame);
- // Increments the current sequence number in QuicPacketCreator and sets it
- // into the packet and returns the new sequence number.
- QuicPacketSequenceNumber SetNewSequenceNumber(QuicPacket* packet);
-
QuicPacketSequenceNumber sequence_number() const {
return sequence_number_;
}
@@ -52,30 +52,27 @@ class NET_EXPORT_PRIVATE QuicPacketCreator : public QuicFecBuilderInterface {
// num_serialized is set to the number of frames serialized into the packet.
PacketPair SerializeFrames(const QuicFrames& frames, size_t* num_serialized);
- // Converts a raw payload to a series of QuicPackets. Returns the number of
- // bytes consumed from data.
+ // Converts a raw payload to a series of QuicPackets and matching frames in
+ // those packets. Returns the number of bytes consumed from data.
// If data is empty and fin is true, the expected behavior is to consume the
// fin but return 0.

Powered by Google App Engine
This is Rietveld 408576698